#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Generates 2D coordinates
#############################################################################

import sys
from openeye import oechem
from openeye import oedepict


def main(argv=[__name__]):

    itf = oechem.OEInterface(InterfaceData)
    oedepict.OEConfigurePrepareDepictionOptions(itf,
                                                oedepict.OEPrepareDepictionSetup_SuppressHydrogens |
                                                oedepict.OEPrepareDepictionSetup_DepictOrientation)

    if not oechem.OEParseCommandLine(itf, argv):
        oechem.OEThrow.Fatal("Unable to interpret command line!")

    iname = itf.GetString("-in")
    ifs = oechem.oemolistream()
    if not ifs.open(iname):
        oechem.OEThrow.Fatal("Cannot open input file!")

    ofs = oechem.oemolostream(".sdf")
    if itf.HasString("-out"):
        oname = itf.GetString("-out")
        if not ofs.open(oname):
            oechem.OEThrow.Fatal("Cannot open output file!")
        if not oechem.OEIs2DFormat(ofs.GetFormat()):
            oechem.OEThrow.Fatal("Invalid output format for 2D coordinates")

    if itf.HasString("-ringdict"):
        rdfname = itf.GetString("-ringdict")
        if not oechem.OEInit2DRingDictionary(rdfname):
            oechem.OEThrow.Warning("Cannot use user-defined ring dictionary!")

    popts = oedepict.OEPrepareDepictionOptions()
    oedepict.OESetupPrepareDepictionOptions(popts, itf)
    popts.SetClearCoords(True)

    for mol in ifs.GetOEGraphMols():
        oedepict.OEPrepareDepiction(mol, popts)
        oechem.OEWriteMolecule(ofs, mol)

    return 0


#############################################################################
# INTERFACE
#############################################################################

InterfaceData = """
!BRIEF [-in] <input> [-out] <output> [-ringdict] <rd file>

!CATEGORY "input/output options :"

  !PARAMETER -in
    !ALIAS -i
    !TYPE string
    !REQUIRED true
    !KEYLESS 1
    !VISIBILITY simple
    !BRIEF Input filename
  !END

  !PARAMETER -out
    !ALIAS -o
    !TYPE string
    !REQUIRED false
    !KEYLESS 2
    !VISIBILITY simple
    !BRIEF Output filename
  !END

  !PARAMETER -ringdict
    !ALIAS -rd
    !TYPE string
    !REQUIRED false
    !VISIBILITY simple
    !BRIEF User-defined 2D ring dictionary
    !DETAIL
        2D ring dictionaries can be generated by the following OEChem examples:
        C++    - createringdict.cpp
        Python - createringdict.py
        Java   - CreateRingDict.java
        C#     - CreateRingDict.cs
  !END

!END
"""

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict
from openeye import oegrapheme


# @ <SNIPPET-2DPROPMAP-PCHARGE>
def SetPartialCharge(mol, tagname):
    oechem.OEMMFFAtomTypes(mol)
    oechem.OEMMFF94PartialCharges(mol)

    tag = oechem.OEGetTag(tagname)
    for atom in mol.GetAtoms():
        atom.SetData(tag, atom.GetPartialCharge())


mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "Cc1cc(cc(c1[N+](=O)[O-])F)[N+]#C")
oedepict.OEPrepareDepiction(mol)

tagname = "PartialCharge"
SetPartialCharge(mol, tagname)

width, height = 450, 350
opts = oedepict.OE2DMolDisplayOptions(width, height, oedepict.OEScale_AutoScale)
opts.SetAtomColorStyle(oedepict.OEAtomColorStyle_WhiteMonochrome)
opts.SetTitleLocation(oedepict.OETitleLocation_Hidden)
opts.SetScale(oegrapheme.OEGetMoleculeSurfaceScale(mol, opts))
disp = oedepict.OE2DMolDisplay(mol, opts)

propmap = oegrapheme.OE2DPropMap(opts.GetBackgroundColor())
propmap.SetNegativeColor(oechem.OEDarkRed)
propmap.SetPositiveColor(oechem.OEDarkBlue)
propmap.Render(disp, tagname)

oedepict.OERenderMolecule("Draw2DPropMapPartialCharge.png", disp)
# @ </SNIPPET-2DPROPMAP-PCHARGE>
oedepict.OERenderMolecule("Draw2DPropMapPartialCharge.pdf", disp)



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict
from openeye import oegrapheme


# @ <SNIPPET-2DPROPMAP-PCHARGE-MULTI>
def SetPartialCharge(mol, tagname, minvalue, maxvalue):
    oechem.OEMMFFAtomTypes(mol)
    oechem.OEMMFF94PartialCharges(mol)

    tag = oechem.OEGetTag(tagname)
    for atom in mol.GetAtoms():
        charge = atom.GetPartialCharge()
        atom.SetData(tag, charge)
        minvalue = min(minvalue, charge)
        maxvalue = max(maxvalue, charge)

    return minvalue, maxvalue


smiles = ["c1ccnc(c1)[N+](=O)[O-]",
          "c1ccccc1F",
          "c1ccc(cc1)S(=O)(=O)[O-]"]

minvalue = float("inf")
maxvalue = float("-inf")
tagname = "PartialCharge"

molecules = []
for smi in smiles:
    mol = oechem.OEGraphMol()
    oechem.OESmilesToMol(mol, smi)
    oedepict.OEPrepareDepiction(mol)
    minvalue, maxvalue = SetPartialCharge(mol, tagname, minvalue, maxvalue)
    molecules.append(oechem.OEGraphMol(mol))

width, height = 750, 250
image = oedepict.OEImage(width, height)

rows, cols = 1, 3
grid = oedepict.OEImageGrid(image, rows, cols)

opts = oedepict.OE2DMolDisplayOptions(grid.GetCellWidth(), grid.GetCellHeight(),
                                      oedepict.OEScale_Default)
opts.SetAtomColorStyle(oedepict.OEAtomColorStyle_WhiteMonochrome)
opts.SetTitleLocation(oedepict.OETitleLocation_Hidden)

propmap = oegrapheme.OE2DPropMap(opts.GetBackgroundColor())
propmap.SetNegativeColor(oechem.OEDarkRed)
propmap.SetPositiveColor(oechem.OEDarkBlue)
propmap.SetLegendLocation(oegrapheme.OELegendLocation_Left)

propmap.SetMinValue(minvalue)
propmap.SetMaxValue(maxvalue)

for cell, mol in zip(grid.GetCells(), molecules):
    disp = oedepict.OE2DMolDisplay(mol, opts)
    propmap.Render(disp, tagname)

    oedepict.OERenderMolecule(cell, disp)

oedepict.OEWriteImage("Draw2DPropMapPartialChargeMulti.png", image)
# @ </SNIPPET-2DPROPMAP-PCHARGE-MULTI>
oedepict.OEWriteImage("Draw2DPropMapPartialChargeMulti.pdf", image)



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# Split a multi-conformer database into N chunks keeping molecules
# with the same number of atoms in each chunk. Also caches other
# useful information onto the molecule to improve database load time.

import sys
import os

from openeye import oechem
from openeye import oefastrocs

oepy = os.path.join(os.path.dirname(__file__), "..", "python")
sys.path.insert(0, os.path.realpath(oepy))


def main(argv=[__name__]):
    if len(argv) != 4:
        oechem.OEThrow.Usage("%s <database> <prefix> <n_servers>" % argv[0])

    # input - preserve rotor-offset-compression
    ifs = oechem.oemolistream()
    oechem.OEPreserveRotCompress(ifs)

    ifname = argv[1]
    if not ifs.open(ifname):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[1])

    # output
    prefix = argv[2]
    ext = oechem.OEGetFileExtension(prefix)
    extstrt = len(prefix)
    if ext:
        extstrt = -(len(ext) + 1)
    else:
        ext = oechem.OEGetFileExtension(ifname)
    base = prefix[:extstrt]
    fmt = base + "_%i." + ext

    nservers = int(argv[3])
    outstrms = []
    for i in range(1, nservers + 1):
        ofs = oechem.oemolostream()
        if not ofs.open(fmt % i):
            oechem.OEThrow.Fatal("Unable to open %s for writing" % argv[2])

        outstrms.append(ofs)

    dots = oechem.OEDots(10000, 200, "molecules")
    for mol in ifs.GetOEMols():
        oefastrocs.OEPrepareFastROCSMol(mol)

        nhvyatoms = oechem.OECount(mol, oechem.OEIsHeavy())

        ofs = outstrms[nhvyatoms % nservers]
        oechem.OEWriteMolecule(ofs, mol)

        dots.Update()

    dots.Total()

    for strm in outstrms:
        fname = strm.GetFileName()
        strm.close()
        oechem.OEThrow.Info("Indexing %s" % fname)
        if not oechem.OECreateMolDatabaseIdx(fname):
            oechem.OEThrow.Fatal("Failed to index %s" % fname)

    return 0


if __name__ == '__main__':
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict


# @ <SNIPPET-ATOM-PROP-USER>
class LabelAromaticAtoms(oedepict.OEDisplayAtomPropBase):
    def __init__(self):
        oedepict.OEDisplayAtomPropBase.__init__(self)

    def __call__(self, atom):
        if atom.IsAromatic():
            return "(A)"
        return ""

    def CreateCopy(self):
        # __disown__ is required to allow C++ to take
        # ownership of this object and its memory
        copy = LabelAromaticAtoms()
        return copy.__disown__()


mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "c1cc(N)cc(S(=O)(=O)O)c1")
oedepict.OEPrepareDepiction(mol)

width, height = 300, 200

opts = oedepict.OE2DMolDisplayOptions(width, height, oedepict.OEScale_AutoScale)

atomlabel = LabelAromaticAtoms()
opts.SetAtomPropertyFunctor(atomlabel)

disp = oedepict.OE2DMolDisplay(mol, opts)
oedepict.OERenderMolecule("AtomPropUser.png", disp)
# @ </SNIPPET-ATOM-PROP-USER>
oedepict.OERenderMolecule("AtomPropUser.pdf", disp)



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# generate an exact/SSS SMARTS query from a structure exemplar
#############################################################################

import sys
from openeye import oechem


def ApplySMARTSConstraints(tag, mol, atomFLAGS, bondFLAGS):
    for ats in mol.GetAtoms():
        smarts = oechem.OECreateAtomSmartsString(ats, atomFLAGS)
        if smarts:
            ats.SetStringData(tag, smarts)
    for bds in mol.GetBonds():
        smarts = oechem.OECreateBondSmartsString(bds, bondFLAGS)
        if smarts:
            bds.SetStringData(tag, smarts)


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData, argv)

    if itf.GetBool("-exact") and itf.GetBool("-sss"):
        oechem.OEThrow.Warning("option -exact in use, overrides -sss")

    atomFLAGS = oechem.OESMARTSAtomFlag_AtomExact
    bondFLAGS = oechem.OESMARTSBondFlag_BondExact
    if not itf.GetBool("-exact") and itf.GetBool("-sss"):
        # generalize query for SSS mappings
        atomFLAGS = (
            oechem.OESMARTSAtomFlag_AtomType
            | oechem.OESMARTSAtomFlag_IgnoreArom
        )
        bondFLAGS = oechem.OESMARTSBondFlag_AnyBondType

    ifs = oechem.oemolistream()
    if not ifs.open(itf.GetString("-in")):
        oechem.OEThrow.Fatal("Unable to open {} for input".format(itf.GetString("-in")))

    ofs = None
    if itf.HasString("-out"):
        ofs = oechem.oeofstream()
        if not ofs.open(itf.GetString("-out")):
            oechem.OEThrow.Fatal("Unable to open {} for output".format(itf.GetString("-out")))

    # option flags
    smartsTAG = "makeSMARTS"

    recno = -1
    for mol in ifs.GetOEMols():
        ++recno
        ApplySMARTSConstraints(smartsTAG, mol, atomFLAGS, bondFLAGS)
        smarts = oechem.OECreateSmartsString(mol, smartsTAG)
        if not smarts:
            oechem.OEThrow("{}: error generating SMARTS pattern", recno)
            continue

        if ofs is None:
            print(smarts)
        else:
            # output file specified
            ofs.write("{}\n".format(smarts))

    if ofs is not None:
        ofs.close()

InterfaceData = """
!BRIEF -in mol_exemplar_file [-out <output>]
    !CATEGORY I/O
        !PARAMETER -in 1
          !ALIAS -i
          !TYPE string
          !REQUIRED true
          !BRIEF Input file name
        !END
        !PARAMETER -out 2
          !ALIAS -o
          !TYPE string
          !REQUIRED false
          !BRIEF Output file name to capture the SMARTS pattern (if successful)
        !END
    !END
    !CATEGORY Options
        !PARAMETER -exact 1
          !TYPE bool
          !REQUIRED false
          !DEFAULT false
          !BRIEF generate an exact SMARTS matching pattern from the input exemplar (overrides -sss)
        !END
        !PARAMETER -sss 2
          !TYPE bool
          !REQUIRED false
          !DEFAULT false
          !BRIEF generate a substructure generalized SMARTS matching pattern from the input exemplar
        !END
    !END
!END
"""

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oegrid
from openeye import oespicoli


def main(args):
    if len(args) != 3:
        oechem.OEThrow.Usage("%s <ref> <fit>" % args[0])

    refifs = oechem.oemolistream()
    if not refifs.open(args[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % args[1])

    refmol = oechem.OEGraphMol()
    oechem.OEReadMolecule(refifs, refmol)
    oechem.OEAssignBondiVdWRadii(refmol)

    fitifs = oechem.oemolistream()
    if not fitifs.open(args[2]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % args[2])

    fitmol = oechem.OEGraphMol()
    oechem.OEReadMolecule(fitifs, fitmol)
    oechem.OEAssignBondiVdWRadii(fitmol)

    # Map the reference molecule onto a grid
    grd = oegrid.OEScalarGrid()
    oegrid.OEMakeMolecularGaussianGrid(grd, refmol, 0.5)

    # Get the total volume of the reference molecule
    refsrf = oespicoli.OESurface()
    oespicoli.OEMakeSurfaceFromGrid(refsrf, grd, 1.0)
    totalv = oespicoli.OESurfaceVolume(refsrf)

    # Mask out the fit molecule
    oegrid.OEMaskGridByMolecule(grd, fitmol)

    # Find how much of the reference volume is remaining
    fitsrf = oespicoli.OESurface()
    oespicoli.OEMakeSurfaceFromGrid(fitsrf, grd, 1.0)
    remaining = oespicoli.OESurfaceVolume(fitsrf)

    print("Percent overlap: %f" % ((1 - remaining/totalv) * 100))

    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
import sys
from openeye import oechem


def CalcResCounts(mol):
    if not oechem.OEHasResidues(mol):
        oechem.OEPerceiveResidues(mol, oechem.OEPreserveResInfo_All)
    resCt = 0
    hetCt = 0
    prevRes = oechem.OEResidue()
    for atom in mol.GetAtoms():
        thisRes = oechem.OEAtomGetResidue(atom)
        if not oechem.OESameResidue(prevRes, thisRes):
            resCt += 1
            if thisRes.IsHetAtom():
                hetCt += 1
            prevRes = thisRes
    print("Molecule: %s" % mol.GetTitle())
    print("Residues: %d (%d hets)" % (resCt, hetCt))


def main(argv=[__name__]):
    if len(argv) != 2:
        oechem.OEThrow.Usage("%s <mol-infile>" % argv[0])

    ims = oechem.oemolistream()
    if not ims.open(argv[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[1])

    for mol in ims.GetOEGraphMols():
        CalcResCounts(mol)


if __name__ == "__main__":
    sys.exit(main(sys.argv))

# @ </SNIPPET>



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict

###############################################################
# USED TO GENERATE CODE SNIPPETS FOR THE OEDEPICT DOCUMENTATION
###############################################################

mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "c1cc(N)cc(S(=O)(=O)O)c1")
oedepict.OEPrepareDepiction(mol)

width, height = 300, 200

opts = oedepict.OE2DMolDisplayOptions(width, height, oedepict.OEScale_AutoScale)
disp = oedepict.OE2DMolDisplay(mol, opts)

pred = oechem.OEIsAromaticBond()
for bond in mol.GetBonds(pred):
    # @ <SNIPPET-OE2DMOLDISPLAY-GETBONDDISPLAY>
    bdisp = disp.GetBondDisplay(bond)
    if bdisp is not None and bdisp.IsVisible():
        # do something
        pass
    # @ </SNIPPET-OE2DMOLDISPLAY-GETBONDDISPLAY>

# @ <SNIPPET-OE2DMOLDISPLAY-GETBONDDISPLAYS-PREDICATE>
for bdisp in disp.GetBondDisplays(oechem.OEIsAromaticBond()):
    if bdisp.IsVisible():
        # do something
        pass
# @ </SNIPPET-OE2DMOLDISPLAY-GETBONDDISPLAYS-PREDICATE>



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict

###############################################################
# USED TO GENERATE CODE SNIPPETS FOR THE OEDEPICT DOCUMENTATION
###############################################################


# @ <SNIPPET-OEADDHIGHLIGHTING-PREDICATE>
class Pred6MemAromAtom(oechem.OEUnaryAtomPred):
    def __call__(self, atom):
        return atom.IsAromatic() and oechem.OEAtomIsInAromaticRingSize(atom, 6)


class Pred6MemAromBond(oechem.OEUnaryBondPred):
    def __call__(self, bond):
        return bond.IsAromatic() and oechem.OEBondIsInAromaticRingSize(bond, 6)


def OEAddHighlighting_Predicate(disp):
    highlightstyle = oedepict.OEHighlightByBallAndStick(oechem.OELightGreen)
    oedepict.OEAddHighlighting(disp, highlightstyle, Pred6MemAromAtom())
    oedepict.OEAddHighlighting(disp, highlightstyle, Pred6MemAromBond())


def OEAddHighlighting_AtomAndBondPredicate(disp):
    highlightstyle = oedepict.OEHighlightByBallAndStick(oechem.OELightGreen)
    oedepict.OEAddHighlighting(disp, highlightstyle, Pred6MemAromAtom(), Pred6MemAromBond())
# @ </SNIPPET-OEADDHIGHLIGHTING-PREDICATE>


# @ <SNIPPET-OEADDHIGHLIGHTING-OEMATCH>
def OEAddHighlighting_OEMatch(disp):
    subs = oechem.OESubSearch("a1aaaaa1")
    unique = True
    highlightstyle = oedepict.OEHighlightByBallAndStick(oechem.OELightGreen)
    for match in subs.Match(disp.GetMolecule(), unique):
        oedepict.OEAddHighlighting(disp, highlightstyle, match)
# @ </SNIPPET-OEADDHIGHLIGHTING-OEMATCH>


# @ <SNIPPET-OEADDHIGHLIGHTING-OEATOMBONDSET>
def OEAddHighlighting_OEAtomBondSet(disp):
    mol = disp.GetMolecule()
    abset = oechem.OEAtomBondSet(mol.GetAtoms(Pred6MemAromAtom()),
                                 mol.GetBonds(Pred6MemAromBond()))

    highlightstyle = oedepict.OEHighlightByBallAndStick(oechem.OELightGreen)
    oedepict.OEAddHighlighting(disp, highlightstyle, abset)
# @ </SNIPPET-OEADDHIGHLIGHTING-OEATOMBONDSET>


# @ <SNIPPET-OEADDHIGHLIGHTING-OESUBSEARCH>
def OEAddHighlighting_OESubSearch(disp):
    subsearch = oechem.OESubSearch("a1aaaaa1")
    highlightstyle = oedepict.OEHighlightByBallAndStick(oechem.OELightGreen)
    oedepict.OEAddHighlighting(disp, highlightstyle, subsearch)
# @ </SNIPPET-OEADDHIGHLIGHTING-OESUBSEARCH>

########################################################################
#
########################################################################


mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "c1ccnc2c1[nH]c3c2cccc3")
oedepict.OEPrepareDepiction(mol)

width, height = 250, 180
opts = oedepict.OE2DMolDisplayOptions(width, height, oedepict.OEScale_AutoScale)
opts.SetTitleLocation(oedepict.OETitleLocation_Hidden)

disp = oedepict.OE2DMolDisplay(mol, opts)
OEAddHighlighting_Predicate(disp)
oedepict.OERenderMolecule("OEAddHighlighting-OEHighlightBase-Predicate.png", disp)
oedepict.OERenderMolecule("OEAddHighlighting-OEHighlightBase-Predicate.pdf", disp)

disp = oedepict.OE2DMolDisplay(mol, opts)
OEAddHighlighting_AtomAndBondPredicate(disp)
oedepict.OERenderMolecule("OEAddHighlighting-OEHighlightBase-AtomAndBondPredicate.png", disp)
oedepict.OERenderMolecule("OEAddHighlighting-OEHighlightBase-AtomAndBondPredicate.pdf", disp)

disp = oedepict.OE2DMolDisplay(mol, opts)
OEAddHighlighting_OEMatch(disp)
oedepict.OERenderMolecule("OEAddHighlighting-OEHighlightBase-OEMatch.png", disp)
oedepict.OERenderMolecule("OEAddHighlighting-OEHighlightBase-OEMatch.pdf", disp)

disp = oedepict.OE2DMolDisplay(mol, opts)
OEAddHighlighting_OEAtomBondSet(disp)
oedepict.OERenderMolecule("OEAddHighlighting-OEHighlightBase-OEAtomBondSet.png", disp)
oedepict.OERenderMolecule("OEAddHighlighting-OEHighlightBase-OEAtomBondSet.pdf", disp)

disp = oedepict.OE2DMolDisplay(mol, opts)
OEAddHighlighting_OESubSearch(disp)
oedepict.OERenderMolecule("OEAddHighlighting-OEHighlightBase-OESubSearch.png", disp)
oedepict.OERenderMolecule("OEAddHighlighting-OEHighlightBase-OESubSearch.pdf", disp)



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Appends rings to an existing 2D rings dictionary
#############################################################################

import sys
from openeye import oechem


def main(argv=[__name__]):

    itf = oechem.OEInterface(InterfaceData, argv)

    ifname = itf.GetString("-in")
    irdfname = itf.GetString("-inringdict")
    ordfname = itf.GetString("-outringdict")

    ifs = oechem.oemolistream()
    if not ifs.open(ifname):
        oechem.OEThrow.Fatal("Unable to open %s for reading!" % ifname)

    if not oechem.OEIs2DFormat(ifs.GetFormat()):
        oechem.OEThrow.Fatal("Invalid input file format for 2D coordinates!")

    if not oechem.OEIsValid2DRingDictionary(irdfname):
        oechem.OEThrow.Fatal("Invalid ring dirctinary file!")

    ringdict = oechem.OE2DRingDictionary(irdfname)

    nrrings = ringdict.NumRings()

    dots = oechem.OEDots(10000, 100, "molecules")

    for mol in ifs.GetOEGraphMols():
        dots.Update()
        ringdict.AddRings(mol)

    dots.Total()

    nrnewrings = ringdict.NumRings() - nrrings
    oechem.OEThrow.Info("%d new ring templates have been added!" % nrnewrings)

    oechem.OEWrite2DRingDictionary(ordfname, ringdict)

    return 0


#############################################################################
# INTERFACE
#############################################################################

InterfaceData = """
!BRIEF [-in] <input> [-inringdict] <input ringdict> [-outringdict] <output ringdict>

!CATEGORY "input/output options :"

  !PARAMETER -in
    !ALIAS -i
    !TYPE string
    !REQUIRED true
    !KEYLESS 1
    !VISIBILITY simple
    !BRIEF Input 2D molecule filename
  !END

  !PARAMETER -inringdict
    !ALIAS -ird
    !TYPE string
    !REQUIRED true
    !KEYLESS 2
    !VISIBILITY simple
    !BRIEF Input ring dictionary OEB filename
    !DETAIL
        2D ring dictionaries can be generated by the following OEChem examples:
        C++    - createringdict.cpp
        Python - createringdict.py
        Java   - CreateRingDict.java
        C#     - CreateRingDict.cs
  !END

  !PARAMETER -outringdict
    !ALIAS -ord
    !TYPE string
    !REQUIRED true
    !KEYLESS 3
    !VISIBILITY simple
    !BRIEF Output ring dictionary OEB filename
  !END

!END
"""


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Count the number of cis amide (omega) residue bonds in a protein
#############################################################################
import sys
import math
from openeye import oechem


def CisCheck(ifs):
    nrmol = 0
    nrcis = 0
    mol = oechem.OEGraphMol()
    while oechem.OEReadMolecule(ifs, mol):
        nrmol += 1
        print("===========================================================")
        print("Molecule: %s   Title: %s" % (nrmol, mol.GetTitle()))
        if not oechem.OEHasResidues(mol):
            oechem.OEPerceiveResidues(mol, oechem.OEPreserveResInfo_All)
        hv = oechem.OEHierView(mol)
        resiter = oechem.ConstOEHierResidueIter()
        resiter = hv.GetResidues()
        while (resiter.IsValid()):
            res = resiter.Target()
            resiter.Next()
            if not oechem.OEIsStandardProteinResidue(res):
                continue
            torsion = oechem.OEGetTorsion(res, oechem.OEProtTorType_Omega)
            if torsion != -100.0:
                if torsion < math.pi/2.0 and torsion > -math.pi/2.0:
                    if resiter.IsValid():
                        nextres = resiter.Target()
                        oenextres = nextres.GetOEResidue()
                        if oechem.OEGetResidueIndex(oenextres) == oechem.OEResidueIndex_PRO:
                            continue
                    nrcis += 1
                    oeres = res.GetOEResidue()
                    print("%s %s %2d omega torsion = %.2f degree" % (oeres.GetName(),
                                                                     oeres.GetChainID(),
                                                                     oeres.GetResidueNumber(),
                                                                     torsion*oechem.cvar.Rad2Deg))
        print(" %d cis amide bond(s) identified\n" % nrcis)


if __name__ == "__main__":
    if len(sys.argv) != 2:
        oechem.OEThrow.Usage("cischeck.py <infile>")
    ifs = oechem.oemolistream()
    if not ifs.open(sys.argv[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % sys.argv[1])
    CisCheck(ifs)



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys

from openeye import oechem


def main(argv=[__name__]):
    if len(argv) != 2:
        oechem.OEThrow.Usage("ToggleInterContour.py <receptor>")

    du = oechem.OEDesignUnit()
    if not oechem.OEReadDesignUnit(argv[1], du):
        oechem.OEThrow.Fatal("Cannot read receptor du file")

    if not du.HasReceptor():
        oechem.OEThrow.Fatal("Design unit %s does not have a receptor" % du.GetTitle())

    # @ <SNIPPET-TOGGLE-INNER-CONTOUR-1>
    receptor = du.GetReceptor()
    innerContourLevel = receptor.GetInnerContourLevel()
    receptor.SetInnerContourLevel(-innerContourLevel)
    # @ </SNIPPET-TOGGLE-INNER-CONTOUR-1>

    if innerContourLevel > 0.0:
        oechem.OEThrow.Info("Toggling inner contour off")
    else:
        oechem.OEThrow.Info("Toggling inner contour on")

    if not oechem.OEWriteDesignUnit(argv[1], du):
        oechem.OEThrow.Fatal("Unable to write receptor")


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Utility to perform a matched pair analysis on a set of structures
#  and save the index for subsequent analysis using a multithreaded API
# ---------------------------------------------------------------------------
# CreateMMPIndexThreaded.py index_mols output_index
#
# index_mols: filename of input molecules to analyze
# output_index: filename of MMP index
#############################################################################

from openeye import oechem
from openeye import oemedchem
import sys


def MMPIndex(itf):
    # checking input structures
    ifsindex = oechem.oemolistream()
    if not ifsindex.open(itf.GetString("-input")):
        oechem.OEThrow.Fatal("Unable to open {} for reading"
                             .format(itf.GetString("-input")))
    ifsindex.close()

    verbose = itf.GetBool("-verbose")
    vverbose = itf.GetBool("-vverbose")
    if vverbose:
        verbose = True

    # output index file
    mmpindexfile = itf.GetString("-output")
    if not oemedchem.OEIsMatchedPairAnalyzerFileType(mmpindexfile):
        oechem.OEThrow.Fatal("Output file is not a matched pair index type - \
                             needs .mmpidx extension: {}" .format(mmpindexfile))

    # create options class with defaults
    mmpopts = oemedchem.OEMatchedPairAnalyzerOptions()
    # set up options from command line
    if not oemedchem.OESetupMatchedPairIndexOptions(mmpopts, itf):
        oechem.OEThrow.Fatal("Error setting matched pair indexing options!")

    if verbose:
        if not mmpopts.HasIndexableFragmentHeavyAtomRange():
            oechem.OEThrow.Info("Indexing all fragments")
        else:
            oechem.OEThrow.Info("Limiting fragment cores to {0:.2f}-{1:.2f}% of input molecules"
                                .format(mmpopts.GetIndexableFragmentRangeMin(),
                                        mmpopts.GetIndexableFragmentRangeMax()))

    if itf.GetInt("-maxrec") and verbose:
        oechem.OEThrow.Info("Indexing a maximum of {} records"
                            .format(itf.GetInt("-maxrec")))

    if itf.GetBool("-exportcompress"):
        if verbose:
            oechem.OEThrow.Info("Removing singleton index nodes from index")
        if not mmpopts.SetOptions(mmpopts.GetOptions() |
                                  oemedchem.OEMatchedPairOptions_ExportCompression):
            oechem.OEThrow.Warning("Error enabling export compression!")

    # set indexing options
    indexopts = oemedchem.OECreateMMPIndexOptions(mmpopts)

    # set requested verbosity setting
    if vverbose:
        indexopts.SetVerbose(2)
    elif verbose:
        indexopts.SetVerbose(1)

    # limit number of records to process
    indexopts.SetMaxRecord(itf.GetInt("-maxrec"))

    # set number of threads to use
    indexopts.SetNumThreads(itf.GetInt("-threads"))
    if verbose:
        if not indexopts.GetNumThreads():
            oechem.OEThrow.Info("Using the maximum number of threads available")
        else:
            oechem.OEThrow.Info("Limiting indexing to {} thread(s)"
                                .format(indexopts.GetNumThreads()))

    errs = None
    if itf.GetBool("-nowarnings"):
        errs = oechem.oeosstream()
        oechem.OEThrow.SetOutputStream(errs)

    if verbose:
        oechem.OEThrow.Info("Threaded indexing of {}, all SD data will be preserved".format(itf.GetString("-input")))

    # create index
    indexstatus = oemedchem.OECreateMMPIndexFile(mmpindexfile,
                                                 itf.GetString("-input"),
                                                 indexopts)

    dupes = 0
    if errs is not None:
        oechem.OEThrow.SetOutputStream(oechem.oeout)
        for err in errs.str().decode().split('\n'):
            err = err.rstrip()
            if not err:
                continue
            if verbose:
                oechem.OEThrow.Info(err)
            if 'ignoring duplicate molecule,' in err:
                dupes += 1

    if not indexstatus.IsValid():
        oechem.OEThrow.Fatal('Invalid status returned from indexing!')

    if not indexstatus.GetTotalMols():
        oechem.OEThrow.Fatal('No records in index structure file: {}'
                             .format(itf.GetString("-input")))

    if dupes:
        oechem.OEThrow.Info('Found {} duplicate structures during indexing'
                            .format(dupes))

    if not indexstatus.GetNumMatchedPairs():
        oechem.OEThrow.Fatal('No matched pairs found from indexing, ' +
                             'use -fragGe,-fragLe options to extend indexing range')

    # return some status information
    oechem.OEThrow.Info("Records: {}, Indexed: {}, matched pairs: {:,d}"
                        .format(indexstatus.GetTotalMols(),
                                indexstatus.GetNumMols(),
                                indexstatus.GetNumMatchedPairs()))

    return 0


############################################################
InterfaceData = """
# createmmpindexthreaded interface file
!CATEGORY CreateMMPIndexThreaded

    !CATEGORY I/O
        !PARAMETER -input 1
          !ALIAS -in
          !TYPE string
          !REQUIRED true
          !BRIEF Input filename of structures to index
          !KEYLESS 1
        !END

        !PARAMETER -output 2
          !ALIAS -out
          !TYPE string
          !REQUIRED true
          !BRIEF Output filename for serialized MMP index
          !KEYLESS 2
        !END
    !END

    !CATEGORY indexing_options
        !PARAMETER -maxrec 1
           !TYPE int
           !DEFAULT 0
           !LEGAL_RANGE 0 inf
           !BRIEF process at most -maxrec records from -input (0: all)
        !END
        !PARAMETER -threads 2
           !TYPE int
           !DEFAULT 0
           !LEGAL_RANGE 0 inf
           !BRIEF limit number of indexing threads to -threads (0:default)
        !END
        !PARAMETER -exportcompress 3
          !TYPE bool
          !DEFAULT 0
          !BRIEF Whether to remove singleton nodes on export of the MMP index
          !DETAIL
               True indicates no additional structures will be added to the index
        !END
        !PARAMETER -nowarnings 4
           !TYPE bool
           !DEFAULT 1
           !BRIEF suppress warning messages from indexing -input (default: True)
        !END
        !PARAMETER -verbose 5
           !TYPE bool
           !DEFAULT 0
           !BRIEF generate verbose output
        !END
        !PARAMETER -vverbose 6
           !TYPE bool
           !DEFAULT 0
           !BRIEF generate very verbose output
        !END
    !END
!END
"""


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData)
    oemedchem.OEConfigureMatchedPairIndexOptions(itf)

    if not oechem.OEParseCommandLine(itf, argv):
        oechem.OEThrow.Fatal("Unable to interpret command line!")

    MMPIndex(itf)


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict

# @ <SNIPPET-NO-ALIGNMENT>
refmol = oechem.OEGraphMol()
oechem.OESmilesToMol(refmol, "C[C@H](C(=O)N1CCC[C@H]1C(=O)O)OC(=O)[C@@H](Cc2ccccc2)S")
oedepict.OEPrepareDepiction(refmol)

fitmol = oechem.OEGraphMol()
oechem.OESmilesToMol(fitmol, "C[C@H](C(=O)N1CCC[C@H]1C(=O)O)NC(=O)[C@@H](Cc2ccccn2)S")
oedepict.OEPrepareDepiction(fitmol)

image = oedepict.OEImage(500, 300)

rows, cols = 1, 2
grid = oedepict.OEImageGrid(image, rows, cols)

opts = oedepict.OE2DMolDisplayOptions(grid.GetCellWidth(), grid.GetCellHeight(),
                                      oedepict.OEScale_AutoScale)
opts.SetTitleLocation(oedepict.OETitleLocation_Hidden)

refscale = oedepict.OEGetMoleculeScale(refmol, opts)
fitscale = oedepict.OEGetMoleculeScale(fitmol, opts)
opts.SetScale(min(refscale, fitscale))

refdisp = oedepict.OE2DMolDisplay(refmol, opts)
fitdisp = oedepict.OE2DMolDisplay(fitmol, opts)

refcell = grid.GetCell(1, 1)
oedepict.OERenderMolecule(refcell, refdisp)

fitcell = grid.GetCell(1, 2)
oedepict.OERenderMolecule(fitcell, fitdisp)

oedepict.OEWriteImage("FPNoAlignment.png", image)
# @ </SNIPPET-NO-ALIGNMENT>
oedepict.OEWriteImage("FPNoAlignment.pdf", image)



# CONFIDENTIAL. (C) 2022 Cadence Design Systems, Inc. (Cadence)
# All rights reserved.
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO CADENCE
# AND IS SUBJECT TO THE FULL PROTECTION OF COPYRIGHT AND TRADE SECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from Cadence is strictly
# prohibited and illegal.  De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact Cadence at eyesopen.com/legal if you have any questions
# about this warning.

import os
import sys
import platform
from .openeye_platform import openeye_python_version, openeye_platform, openeye_python_compilers, openeye_python_version

def SearchForCompatibleLibDirectory(compatible_compilers, archlist):
    base = os.path.abspath(os.path.dirname(__file__))
    pyver = openeye_python_version()

    tried = []
    for comp in compatible_compilers:
        for arch in archlist:
            if arch.endswith("x86"):
                if platform.architecture()[0] == "64bit":
                    raise ImportError("On x86 machine trying to use a 64-bit python")

            archname = '-'.join([arch, comp])

            tried.append(archname)
            dlls = os.path.join(base, archname)
            if os.path.exists(dlls):
                return tried, dlls

    return tried, None

def FindOpenEyeDLLSDirectory():
    archlist = '-'.join(openeye_platform())
    if "OE_PIP_ARCH" in os.environ:
        archlist = os.environ["OE_PIP_ARCH"].split(":")

    compatible_compilers = openeye_python_compilers()
    tried, dlls = SearchForCompatibleLibDirectory(compatible_compilers, archlist)
    if dlls is not None:
        return dlls

    base = os.path.abspath(os.path.dirname(__file__))

    # allow osx-es to use each other as a last resort
    if sys.platform == "darwin":
        pyver = openeye_python_version()
        for fname in os.listdir(base):
            dlls = os.path.join(base, fname)
            if (pyver in fname and
                "osx" in fname and
                os.path.isdir(dlls)):
                return dlls

    # allow linuxes to use each other as a last resort
    if sys.platform.startswith("linux"):
        pyver = openeye_python_version()
        for fname in os.listdir(base):
            dlls = os.path.join(base, fname)
            if (pyver in fname and
                "g++" in fname and
                "osx" not in fname and
                os.path.isdir(dlls)):
                return dlls

    installed = []
    for fname in os.listdir(base):
        if os.path.isdir(os.path.join(base, fname)):
            installed.append(fname)

    msg = """Unable to find OpenEye python toolkit installation for this architecture.
    The architecture for this python interpreter is: %s
    The directory searched for architecture specific libraries: %s
    Installations found in that directory:
    \t%s
    Please make sure the installed tar-ball exactly matches %s
    """
    arches = repr(tried)
    raise ImportError(msg % (arches, base, "\n\t".join(installed), arches))

if not sys.platform.startswith("win"):
    OPENEYE_DLLS = FindOpenEyeDLLSDirectory()

def OEGetModule(name):
    if sys.platform == "darwin" and "DYLD_LIBRARY_PATH" in os.environ:
        # check for clash
        soname = "%s.so" % name
        for dname in os.environ["DYLD_LIBRARY_PATH"].split(":"):
            if (dname and
                os.path.exists(os.path.join(dname, soname)) and
                not os.path.samefile(dname, OPENEYE_DLLS)):
                raise ImportError("Conflict found loading %r. Please remove %r from DYLD_LIBRARY_PATH." %
                                  (soname, soname))

    import importlib
    # find the module
    spec = importlib.machinery.PathFinder().find_spec(name, [OPENEYE_DLLS])

    # actually load the module
    mod = importlib.util.module_from_spec(spec)
    spec.loader.exec_module(mod)

    return mod

if sys.platform.startswith("win"):
    def OEGetModule(name):
        raise ImportError("OEGetModule should never be called on Windows")




#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Aligns the fit molecule(s) based on their maximum common substructure
# with the reference molecule.
#############################################################################

import sys
from openeye import oechem
from openeye import oedepict


def main(argv=[__name__]):

    itf = oechem.OEInterface(InterfaceData)

    if not oechem.OEParseCommandLine(itf, argv):
        oechem.OEThrow.Fatal("Unable to interpret command line!")

    rname = itf.GetString("-ref")
    fname = itf.GetString("-fit")
    oname = itf.GetString("-out")

    rifs = oechem.oemolistream()
    if not rifs.open(rname):
        oechem.OEThrow.Fatal("Cannot open reference molecule file!")

    refmol = oechem.OEGraphMol()
    if not oechem.OEReadMolecule(rifs, refmol):
        oechem.OEThrow.Fatal("Cannot read reference molecule!")

    fifs = oechem.oemolistream()
    if not fifs.open(fname):
        oechem.OEThrow.Fatal("Cannot open align molecule file!")

    ofs = oechem.oemolostream()
    if not ofs.open(oname):
        oechem.OEThrow.Fatal("Cannot open output file!")
    if not oechem.OEIs2DFormat(ofs.GetFormat()):
        oechem.OEThrow.Fatal("Invalid output format for 2D coordinates")

    oedepict.OEPrepareDepiction(refmol)

    mcss = oechem.OEMCSSearch(oechem.OEMCSType_Approximate)
    atomexpr = oechem.OEExprOpts_DefaultAtoms
    bondexpr = oechem.OEExprOpts_DefaultBonds
    mcss.Init(refmol, atomexpr, bondexpr)
    mcss.SetMCSFunc(oechem.OEMCSMaxBondsCompleteCycles())

    oechem.OEWriteConstMolecule(ofs, refmol)

    for fitmol in fifs.GetOEGraphMols():
        alignres = oedepict.OEPrepareAlignedDepiction(fitmol, mcss)
        if alignres.IsValid():
            oechem.OEThrow.Info("%s  mcs size: %d" % (fitmol.GetTitle(), alignres.NumAtoms()))
            oechem.OEWriteMolecule(ofs, fitmol)

    return 0


#############################################################################
# INTERFACE
#############################################################################

InterfaceData = '''
!BRIEF [-ref] <input> [-fit] <input> [-out] <output>

!CATEGORY "input/output options :"

    !PARAMETER -ref
      !ALIAS -r
      !TYPE string
      !REQUIRED true
      !KEYLESS 1
      !VISIBILITY simple
      !BRIEF Ref filename
    !END

    !PARAMETER -fit
      !ALIAS -f
      !TYPE string
      !REQUIRED true
      !KEYLESS 2
      !VISIBILITY simple
      !BRIEF Align filename
    !END

    !PARAMETER -out
      !ALIAS -o
      !TYPE string
      !REQUIRED true
      !KEYLESS 3
      !VISIBILITY simple
      !BRIEF Output filename
    !END

!END
'''

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.
import os
import sqlite3
import sys

from openeye import oesitehopper


def get_info(shdb_file):
    conn = sqlite3.connect(f"file:{shdb_file}?mode=ro", uri=True)
    cursor = conn.cursor()
    res = cursor.execute("SELECT title,lastModifiedDate,SiteHopperToolkitVersion from Info;")
    row = res.fetchone()
    print(f"Path: {os.path.abspath(shdb_file)}")
    print(f"  Title: {row[0]}")
    print(f"  Modified: {row[1]}")
    print(f"  SiteHopper TK version: {row[2]}")

    res = cursor.execute("SELECT * from Version;")
    row = res.fetchone()
    print(f"  version: {row[0]}")

    res = cursor.execute("SELECT count(*) from patches;")
    row = res.fetchone()
    print(f"  Num Patches: {row[0]}")

    res = cursor.execute("SELECT count(*) from designunit;")
    row = res.fetchone()
    print(f"  Num DUs: {row[0]-1}")


def main(args):
    if len(args) != 2:
        print("usage: shdb_info.py <shdbfile>")
        return 0

    shdb = oesitehopper.OESiteHopperDatabase()
    if not os.path.exists(args[1]) or not shdb.Open(args[1], oesitehopper.OESiteHopperDatabaseMode_READONLY):
        print(f"{args[1]} is not a valid SHDB file")
        return 1
    shdb.Close()

    get_info(args[1])
    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))


#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oeff

# //////////////////////////////////////////////////////////////////////////
# The following example demonstrates how to perform ligand optimization   //
# in the context of a protein using a complex force field.                //
# //////////////////////////////////////////////////////////////////////////


class FFOptions(oechem.OEOptions):
    def __init__(self):
        oechem.OEOptions.__init__(self, "FFOptions")

        ffType = oechem.OEStringParameter("-ff", "ff14sb_parsley")
        ffType.AddLegalValue("ff14sb_parsley")
        ffType.AddLegalValue("mmff_amber")
        ffType.AddLegalValue("mmff")
        ffType.SetBrief("Force field type")
        self._fftype = self.AddParameter(ffType)
        pass

    def CreateCopy(self):
        return self

    def GetFF(self):
        ff = self._fftype.GetStringValue()
        if ff == "":
            ff = self._fftype.GetStringDefault()

        if ff == "mmff":
            return oeff.OEMMFFComplex()
        elif ff == "mmff_amber":
            return oeff.OEMMFFAmberComplex()
        else:
            return oeff.OEFF14SBParsleyComplex()


def main(argv=[__name__]):
    ffOpts = FFOptions()
    opts = oechem.OERefInputAppOptions(ffOpts, "FFComplexOpt", oechem.OEFileStringType_Mol3D,
                                       oechem.OEFileStringType_Mol3D, oechem.OEFileStringType_DU, "-protein")
    if oechem.OEConfigureOpts(opts, argv, False) == oechem.OEOptsConfigureStatus_Help:
        return 0
    ffOpts.UpdateValues(opts)

    ifs = oechem.oemolistream()
    if not ifs.open(opts.GetInFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetInFile())

    rfs = oechem.oeifstream()
    if not rfs.open(opts.GetRefFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetRefFile())

    ofs = oechem.oemolostream()
    if not ofs.open(opts.GetOutFile()):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % opts.GetOutFile())

    du = oechem.OEDesignUnit()
    if not oechem.OEReadDesignUnit(rfs, du):
        oechem.OEThrow.Fatal("Failed to read design unit")
    protein = oechem.OEGraphMol()
    du.GetProtein(protein)

    ff = ffOpts.GetFF()
    if not ff.SetupHost(protein):
        oechem.OEThrow.Fatal("Failed to setup protein: %s" % protein.GetTitle())

    for mol in ifs.GetOEMols():
        print("Optimizing", mol.GetTitle())
        if (not ff.Setup(mol)):
            oechem.OEThrow.Warning("Unable to process molecule: title = '%s'" % mol.GetTitle())
            oechem.OEWriteMolecule(ofs, mol)
            continue

        vecCoords = oechem.OEDoubleArray(3*mol.GetMaxAtomIdx())
        for conf in mol.GetConfs():
            oechem.OEThrow.Info("Molecule: %s Conformer: %d" % (mol.GetTitle(), conf.GetIdx()+1))
            conf.GetCoords(vecCoords)

            # Calculate energy
            energy = ff(vecCoords)
            oechem.OEThrow.Info("Initial energy: %0.2f kcal/mol" % energy)

            # Optimize the ligand
            optimizer = oeff.OEBFGSOpt()
            energy = optimizer(ff, vecCoords, vecCoords)
            oechem.OEThrow.Info("Optimized energy: %0.2f kcal/mol" % energy)
            conf.SetCoords(vecCoords)

        oechem.OEWriteMolecule(ofs, mol)

    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Extract the number of Lipinski violations from the table output
#############################################################################
import sys
from openeye import oechem
from openeye import oemolprop


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData)
    oemolprop.OEConfigureFilterParams(itf)

    if not oechem.OEParseCommandLine(itf, argv):
        oechem.OEThrow.Fatal("Unable to interpret command line!")

    iname = itf.GetString("-in")

    ifs = oechem.oemolistream()
    if not ifs.open(iname):
        oechem.OEThrow.Fatal("Cannot open input file!")

    ftype = oemolprop.OEGetFilterType(itf)
    filt = oemolprop.OEFilter(ftype)

    ver = itf.GetInt("-verbose")
    oechem.OEThrow.SetLevel(ver)

    ostr = oechem.oeosstream()
    pwnd = False
    filt.SetTable(ostr, pwnd)

    headers = ostr.str().split(b'\t')
    ostr.clear()  # remove the header row from the stream

    for mol in ifs.GetOEGraphMols():
        filt(mol)

        fields = ostr.str().decode("UTF-8").split('\t')
        ostr.clear()  # remove this row from the stream

        tmpdct = dict(zip(headers, fields))
        print(mol.GetTitle(), tmpdct[b"Lipinski violations"])


#############################################################################
# INTERFACE
#############################################################################

InterfaceData = '''
!BRIEF [-in] <input> [-verbose] <verbose>

!CATEGORY "input/output options :"

    !PARAMETER -in
      !ALIAS -i
      !TYPE string
      !REQUIRED true
      !KEYLESS 1
      !VISIBILITY simple
      !BRIEF Input filename
    !END

!END

!CATEGORY "other options :"

    !PARAMETER -verbose
    !TYPE int
    !REQUIRED false
    !LEGAL_RANGE 2 5
    !DEFAULT 4
    !VISIBILITY simple
    !BRIEF Error level of messages
    !DETAIL
        2 is Verbose
        3 is Info
        4 is Warning
        5 is Error
  !END

!END
'''

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oezap


def PrintHeader(protTitle, ligTitle):
    oechem.OEThrow.Info("\nBinding Energy and Wall Clock Time for %s and %s" %
                        (protTitle, ligTitle))
    oechem.OEThrow.Info("%15s %15s %10s" % ("Focused?", "Energy(kT)", "Time(s)"))


def PrintInfo(focussed, energy, time):
    oechem.OEThrow.Info("%15s %15.3f %10.1f" % (focussed, energy, time))


def CalcBindingEnergy(zap, protein, ligand, cmplx):
    stopwatch = oechem.OEStopwatch()
    stopwatch.Start()

    ppot = oechem.OEFloatArray(protein.GetMaxAtomIdx())
    zap.SetMolecule(protein)
    zap.CalcAtomPotentials(ppot)
    proteinEnergy = 0.0
    for atom in protein.GetAtoms():
        proteinEnergy += ppot[atom.GetIdx()]*atom.GetPartialCharge()
    proteinEnergy *= 0.5

    lpot = oechem.OEFloatArray(ligand.GetMaxAtomIdx())
    zap.SetMolecule(ligand)
    zap.CalcAtomPotentials(lpot)
    ligandEnergy = 0.0
    for atom in ligand.GetAtoms():
        ligandEnergy += lpot[atom.GetIdx()]*atom.GetPartialCharge()
    ligandEnergy *= 0.5

    cpot = oechem.OEFloatArray(cmplx.GetMaxAtomIdx())
    zap.SetMolecule(cmplx)
    zap.CalcAtomPotentials(cpot)
    cmplxEnergy = 0.0
    for atom in cmplx.GetAtoms():
        cmplxEnergy += cpot[atom.GetIdx()]*atom.GetPartialCharge()
    cmplxEnergy *= 0.5

    energy = cmplxEnergy - ligandEnergy - proteinEnergy
    time = stopwatch.Elapsed()

    if zap.IsFocusTargetSet():
        focused = "Yes"
    else:
        focused = "No"

    PrintInfo(focused, energy, time)


def main(argv=[__name__]):
    if len(argv) != 3:
        oechem.OEThrow.Usage("%s <protein> <ligand>" % argv[0])

    ifs = oechem.oemolistream()
    if not ifs.open(argv[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[1])
    protein = oechem.OEGraphMol()
    oechem.OEReadMolecule(ifs, protein)

    if not ifs.open(argv[2]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[2])
    ligand = oechem.OEGraphMol()
    oechem.OEReadMolecule(ifs, ligand)

    oechem.OEAssignBondiVdWRadii(protein)
    oechem.OEMMFFAtomTypes(protein)
    oechem.OEMMFF94PartialCharges(protein)

    oechem.OEAssignBondiVdWRadii(ligand)
    oechem.OEMMFFAtomTypes(ligand)
    oechem.OEMMFF94PartialCharges(ligand)

    cmplx = oechem.OEGraphMol(protein)
    oechem.OEAddMols(cmplx, ligand)

    epsin = 1.0
    spacing = 0.5
    zap = oezap.OEZap()
    zap.SetInnerDielectric(epsin)
    zap.SetGridSpacing(spacing)

    PrintHeader(protein.GetTitle(), ligand.GetTitle())

    CalcBindingEnergy(zap, protein, ligand, cmplx)
    zap.SetFocusTarget(ligand)
    CalcBindingEnergy(zap, protein, ligand, cmplx)

    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oeszybki


def main(argv=[__name__]):
    itf = oechem.OEInterface()
    if not SetupInterface(argv, itf):
        return 1

    ifs = oechem.oemolistream()
    if not ifs.open(itf.GetString("-in")):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % itf.GetString("-in"))

    ofs = oechem.oemolostream()
    if not ofs.open(itf.GetString("-out")):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % itf.GetString("-out"))

    logfile = oechem.oeout
    if itf.HasString("-log"):
        if not logfile.open(itf.GetString("-log")):
            oechem.OEThrow.Fatal("Unable to open %s for writing" % itf.GetString("-log"))

    # Szybki options
    opts = oeszybki.OESzybkiOptions()

    # select run type
    if itf.GetBool("-t"):
        opts.SetRunType(oeszybki.OERunType_TorsionsOpt)
    if itf.GetBool("-n"):
        opts.SetRunType(oeszybki.OERunType_SinglePoint)

    # apply solvent model
    if itf.GetBool("-s"):
        opts.GetSolventOptions().SetSolventModel(oeszybki.OESolventModel_Sheffield)

    # remove attractive VdW forces
    if itf.GetBool("-a"):
        opts.GetGeneralOptions().SetRemoveAttractiveVdWForces(True)

    # Szybki object
    sz = oeszybki.OESzybki(opts)

    # fix atoms
    if itf.HasString("-f"):
        if not sz.FixAtoms(itf.GetString("-f")):
            oechem.OEThrow.Warning("Failed to fix atoms for %s" % itf.GetString("-f"))

    # process molecules
    mol = oechem.OEMol()
    while oechem.OEReadMolecule(ifs, mol):
        logfile.write("\nMolecule %s\n" % mol.GetTitle())
        no_res = True
        for results in sz(mol):
            results.Print(logfile)
            no_res = False

        if no_res:
            oechem.OEThrow.Warning("No results processing molecule: %s" % mol.GetTitle())
            continue
        else:
            oechem.OEWriteMolecule(ofs, mol)

    return 0


InterfaceData = """
!PARAMETER -in
  !TYPE string
  !REQUIRED true
  !BRIEF Input molecule file name.
!END

!PARAMETER -out
  !TYPE string
  !REQUIRED true
  !BRIEF Output molecule file name.
!END

!PARAMETER -log
  !TYPE string
  !REQUIRED false
  !BRIEF Log file name. Defaults to standard out.
!END

!PARAMETER -s
  !TYPE bool
  !DEFAULT false
  !REQUIRED false
  !BRIEF Optimization in solution.
!END

!PARAMETER -t
  !TYPE bool
  !DEFAULT false
  !REQUIRED false
  !BRIEF Optimization of torsions.
!END

!PARAMETER -n
  !TYPE bool
  !DEFAULT false
  !REQUIRED false
  !BRIEF Single point calculation.
!END

!PARAMETER -a
  !TYPE bool
  !DEFAULT false
  !REQUIRED false
  !BRIEF No attractive VdW forces.
!END

!PARAMETER -f
  !TYPE string
  !REQUIRED false
  !BRIEF SMARTS pattern of fixed atoms.
!END
"""


def SetupInterface(argv, itf):
    oechem.OEConfigure(itf, InterfaceData)
    if oechem.OECheckHelp(itf, argv):
        return False
    if not oechem.OEParseCommandLine(itf, argv):
        return False
    if not oechem.OEIsReadable(oechem.OEGetFileType(
                  oechem.OEGetFileExtension(itf.GetString("-in")))):
        oechem.OEThrow.Warning("%s is not a readable input file" % itf.GetString("-in"))
        return False
    if not oechem.OEIsWriteable(oechem.OEGetFileType(
                  oechem.OEGetFileExtension(itf.GetString("-out")))):
        oechem.OEThrow.Warning("%s is not a writable output file" % itf.GetString("-out"))
        return False
    return True


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.


from openeye import oechem
from openeye import oeshape


def oneConf(conf, prep, filename, csvfile):
    csvfile.write("%s_%d" % (conf.GetTitle(), conf.GetIdx()))
    refmol = oechem.OEGraphMol(conf)

    options = oeshape.OEOverlayOptions()
    options.SetOverlapFunc(oeshape.OEGridShapeFunc())
    overlay = oeshape.OEOverlay(options)
    overlay.SetupRef(refmol)

    bfs = oechem.oemolistream(filename)
    fitmol = oechem.OEMol()
    while oechem.OEReadMolecule(bfs, fitmol):
        prep.Prep(fitmol)
        scoreiter = oeshape.OEBestOverlayScoreIter()
        oeshape.OESortOverlayScores(scoreiter, overlay.Overlay(fitmol), oeshape.OEHighestTanimoto(), 1, True)

        for score in scoreiter:
            csvfile.write(",%.2f" % score.GetTanimoto())
    csvfile.write("\n")


def genHeader(filename, csvfile):
    csvfile.write("name")
    ifs = oechem.oemolistream(filename)
    mol = oechem.OEMol()
    while oechem.OEReadMolecule(ifs, mol):
        for conf in mol.GetConfs():
            csvfile.write(",%s_%d" % (conf.GetTitle(), conf.GetIdx()))
    csvfile.write("\n")


def main(argv=[__name__]):
    if len(argv) != 3:
        oechem.OEThrow.Usage("%s <infile> <csvfile>" % argv[0])

    csvfile = open(argv[2], "w")
    genHeader(sys.argv[1], csvfile)

    prep = oeshape.OEOverlapPrep()
    prep.SetAssignColor(False)
    afs = oechem.oemolistream(argv[1])
    for molA in afs.GetOEMols():
        prep.Prep(molA)
        print(molA.GetTitle())
        for conf in molA.GetConfs():
            oneConf(conf, prep, sys.argv[1], csvfile)


if __name__ == "__main__":
    import sys
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# This program concatenates molecules into one file.
# It can be useful for generating ROCS queries or reattach ligands to an
# protein structure
#############################################################################
import sys
from openeye import oechem


def CatMols(infnames, outfname):
    omol = oechem.OEGraphMol()
    for fname in infnames:
        ifs = oechem.oemolistream()
        if ifs.open(fname):
            for imol in ifs.GetOEGraphMols():
                oechem.OEAddMols(omol, imol)
        else:
            oechem.OEThrow.Fatal("Unable to open %s for reading" % fname)

    ofs = oechem.oemolostream()
    if not ofs.open(outfname):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % outfname)

    oechem.OEWriteMolecule(ofs, omol)


Interface = """
!BRIEF -i <infile1> [<infile2>...] -o <outfile>
!PARAMETER -i
  !ALIAS -in
  !TYPE string
  !LIST true
  !REQUIRED true
  !BRIEF input file name(s)
!END
!PARAMETER -o
  !ALIAS -out
  !TYPE string
  !REQUIRED true
  !BRIEF output file name
!END
"""


def main(argv=[__name__]):
    itf = oechem.OEInterface(Interface, argv)

    CatMols(itf.GetStringList("-i"), itf.GetString("-o"))


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oedocking


class MyOptions(oedocking.OEPositOptions):
    def __init__(self):
        oedocking.OEPositOptions.__init__(self)
        param1 = oechem.OEUIntParameter("-numPoses", 1)
        param1.AddLegalRange("1", "20")
        param1.SetBrief("Number of poses to generate")
        self._param1 = self.AddParameter(param1)
        pass

    def GetNumPoses(self):
        if self._param1.GetHasValue():
            return int(self._param1.GetStringValue())
        return int(self._param1.GetStringDefault())

def main(argv=[__name__]):
    positOpts = MyOptions()
    opts = oechem.OERefInputAppOptions(positOpts, "PoseMolecules", oechem.OEFileStringType_Mol3D,
                                       oechem.OEFileStringType_DU, oechem.OEFileStringType_DU, "-receptor")
    if oechem.OEConfigureOpts(opts, argv, False) == oechem.OEOptsConfigureStatus_Help:
        return 0
    positOpts.UpdateValues(opts)

    ifs = oechem.oemolistream()
    if not ifs.open(opts.GetInFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetInFile())

    rfs = oechem.oeifstream()
    if not rfs.open(opts.GetRefFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetRefFile())

    ofs = oechem.oeofstream()
    if not ofs.open(opts.GetOutFile()):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % opts.GetOutFile())

    poser = oedocking.OEPosit(positOpts)
    du = oechem.OEDesignUnit()
    count = 0
    while oechem.OEReadDesignUnit(rfs, du):
        if not du.HasReceptor():
            oechem.OEThrow.Fatal("Design unit %s does not contain a receptor" % du.GetTitle())
        poser.AddReceptor(du)
        count += 1
    if count == 0:
        oechem.OEThrow.Fatal("Receptor input does not contain any design unit")

    oechem.OEThrow.Info("Number of conformers: %d" % positOpts.GetNumPoses())
    oechem.OEThrow.Info("Best Receptor pose flag: %s" % positOpts.GetBestReceptorPoseOnly())
    
    for mcmol in ifs.GetOEMols():
        oechem.OEThrow.Info("posing %s" % mcmol.GetTitle())
        results = oedocking.OEPositResults()
        ret_code = poser.Dock(results, mcmol, positOpts.GetNumPoses())

        if ret_code == oedocking.OEDockingReturnCode_Success:
            for result in results.GetSinglePoseResults():
                posedDU = result.GetDesignUnit()
                posedDU.SetDoubleData(poser.GetName(), result.GetProbability())
                oechem.OEThrow.Info("Receptor used: %s pose probability: %f" % (posedDU.GetTitle(), result.GetProbability()))
                oechem.OEWriteDesignUnit(ofs, posedDU)
        else:
            errMsg = oedocking.OEDockingReturnCodeGetName(ret_code)
            oechem.OEThrow.Warning("%s: %s" % (mcmol.GetTitle(), errMsg))
    return 0

    

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
import os

from openeye import oechem
from openeye import oefastrocs

oepy = os.path.join(os.path.dirname(__file__), "..", "python")
sys.path.insert(0, os.path.realpath(oepy))


def main(argv=[__name__]):
    if len(argv) < 3:
        oechem.OEThrow.Usage("%s <database.oeb> <queries> <hits.oeb>" % argv[0])
        return 0

    # check system
    if not oefastrocs.OEFastROCSIsGPUReady():
        oechem.OEThrow.Info("No supported GPU available!")
        return 0

    # read in database
    dbname = argv[1]

    if oechem.OEIsGZip(dbname):
        oechem.OEThrow.Fatal("%s is an unsupported database file format as it is gzipped.\n"
                             "Preferred formats are .oeb, .sdf or .oez", dbname)

    print("Opening database file %s ..." % dbname)
    dbase = oefastrocs.OEShapeDatabase()
    moldb = oechem.OEMolDatabase()

    if not moldb.Open(dbname):
        oechem.OEThrow.Fatal("Unable to open '%s'" % dbname)

    dots = oechem.OEThreadedDots(10000, 200, "conformers")
    if not dbase.Open(moldb, dots, oefastrocs.OEFastROCSOrientation_AsIs):
        oechem.OEThrow.Fatal("Unable to initialize OEShapeDatabase on '%s'" % dbname)

    # customize search options
    opts = oefastrocs.OEShapeDatabaseOptions()
    opts.SetInitialOrientation(oefastrocs.OEFastROCSOrientation_AsIs)

    opts.SetLimit(50)
    opts.SetMaxConfs(5)
    opts.SetMaxOverlays(opts.GetNumInertialStarts() * opts.GetNumStarts())

    if opts.GetInitialOrientation() == oefastrocs.OEFastROCSOrientation_AsIs:
        numStarts = opts.GetNumStarts()
        numInertialStarts = opts.GetNumInertialStarts()
        oechem.OEThrow.Info("This example will use %u starts & %u inertial starts"
                            % (numStarts, numInertialStarts))

    qfname = argv[2]
    # read in query
    qfs = oechem.oemolistream()
    if not qfs.open(qfname):
        oechem.OEThrow.Fatal("Unable to open '%s'" % qfname)

    query = oechem.OEGraphMol()
    if not oechem.OEReadMolecule(qfs, query):
        oechem.OEThrow.Fatal("Unable to read query from '%s'" % qfname)

    # write out everthing to a similary named file
    ofs = oechem.oemolostream()
    if not ofs.open(argv[3]):
        oechem.OEThrow.Fatal("Unable to open '%s'" % argv[3])
    oechem.OEWriteMolecule(ofs, query)

    print("Searching for %s" % qfname)
    for score in dbase.GetSortedScores(query, opts):
        print("Score for mol %u(conf %u) %f shape %f color" % (
               score.GetMolIdx(), score.GetConfIdx(),
               score.GetShapeTanimoto(), score.GetColorTanimoto()))
        dbmol = oechem.OEMol()
        molidx = score.GetMolIdx()
        if not moldb.GetMolecule(dbmol, molidx):
            print("Unable to retrieve molecule '%u' from the database" % molidx)
            continue

        mol = oechem.OEGraphMol(dbmol.GetConf(oechem.OEHasConfIdx(score.GetConfIdx())))
        oechem.OESetSDData(mol, "ShapeTanimoto", "%.4f" % score.GetShapeTanimoto())
        oechem.OESetSDData(mol, "ColorTanimoto", "%.4f" % score.GetColorTanimoto())
        oechem.OESetSDData(mol, "TanimotoCombo", "%.4f" % score.GetTanimotoCombo())
        score.Transform(mol)

        oechem.OEWriteMolecule(ofs, mol)
    print("Wrote results to %s" % argv[3])

    return 0


if __name__ == '__main__':
    sys.exit(main(sys.argv))



# CONFIDENTIAL. (C) 2022 Cadence Design Systems, Inc. (Cadence)
# All rights reserved.
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO CADENCE
# AND IS SUBJECT TO THE FULL PROTECTION OF COPYRIGHT AND TRADE SECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from Cadence is strictly
# prohibited and illegal.  De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact Cadence at eyesopen.com/legal if you have any questions
# about this warning.


# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")


def swig_import_helper():
    from os.path import dirname
    import importlib.util
    import importlib.abc

    spec = importlib.machinery.PathFinder().find_spec("_oechem", [dirname(__file__)])

    if spec is None:
        # OpenEye Import Statements
        spec = importlib.machinery.PathFinder().find_spec("libs",[dirname(__file__)])
    libs = importlib.util.module_from_spec(spec)

    import sys
    sys.modules[spec.name] = libs
    spec.loader.exec_module(libs)

    assert not sys.platform.startswith('win')

    _oeszmap = libs.OEGetModule('_oeszmap1661')
    return _oeszmap

_oeszmap = swig_import_helper()
del swig_import_helper

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import weakref

OEComponent_Interaction = _oeszmap.OEComponent_Interaction
OEComponent_PSolv = _oeszmap.OEComponent_PSolv
OEComponent_WSolv = _oeszmap.OEComponent_WSolv
OEComponent_VDW = _oeszmap.OEComponent_VDW
OEComponent_ProbeBurial = _oeszmap.OEComponent_ProbeBurial
OEComponent_NumTypes = _oeszmap.OEComponent_NumTypes
OEEnsemble_Interaction = _oeszmap.OEEnsemble_Interaction
OEEnsemble_PSolv = _oeszmap.OEEnsemble_PSolv
OEEnsemble_WSolv = _oeszmap.OEEnsemble_WSolv
OEEnsemble_VDW = _oeszmap.OEEnsemble_VDW
OEEnsemble_ProbeBurial = _oeszmap.OEEnsemble_ProbeBurial
OEEnsemble_InteractionPlusVDW = _oeszmap.OEEnsemble_InteractionPlusVDW
OEEnsemble_OrderParam = _oeszmap.OEEnsemble_OrderParam
OEEnsemble_CalcPoint = _oeszmap.OEEnsemble_CalcPoint
OEEnsemble_Mask = _oeszmap.OEEnsemble_Mask
OEEnsemble_NeutralDiffDeltaH = _oeszmap.OEEnsemble_NeutralDiffDeltaH
OEEnsemble_NeutralDiffTDeltaS = _oeszmap.OEEnsemble_NeutralDiffTDeltaS
OEEnsemble_NeutralDiffDeltaG = _oeszmap.OEEnsemble_NeutralDiffDeltaG
OEEnsemble_NeutralDeltaH = _oeszmap.OEEnsemble_NeutralDeltaH
OEEnsemble_NeutralTDeltaS = _oeszmap.OEEnsemble_NeutralTDeltaS
OEEnsemble_NeutralDeltaG = _oeszmap.OEEnsemble_NeutralDeltaG
OEEnsemble_VacuumDiffDeltaH = _oeszmap.OEEnsemble_VacuumDiffDeltaH
OEEnsemble_VacuumDiffDeltaG = _oeszmap.OEEnsemble_VacuumDiffDeltaG
OEEnsemble_DeltaH = _oeszmap.OEEnsemble_DeltaH
OEEnsemble_TDeltaS = _oeszmap.OEEnsemble_TDeltaS
OEEnsemble_DeltaG = _oeszmap.OEEnsemble_DeltaG
OEEnsemble_NumTypes = _oeszmap.OEEnsemble_NumTypes

OEEnsemble_Default = OEEnsemble_NeutralDiffDeltaG

import openeye.oechem as oechem
class OESzmapEngineOptions(object):
    r"""Proxy of C++ OESzmap::OESzmapEngineOptions class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    __swig_destroy__ = _oeszmap.delete_OESzmapEngineOptions

    def __init__(self, *args):
        r"""
        __init__(OESzmapEngineOptions self) -> OESzmapEngineOptions
        __init__(OESzmapEngineOptions self, OESzmapEngineOptions rhs) -> OESzmapEngineOptions
        """
        _oeszmap.OESzmapEngineOptions_swiginit(self, _oeszmap.new_OESzmapEngineOptions(*args))

    def SetMaskCutoff(self, cutoff: "double") -> "OESzmap::OESzmapEngineOptions &":
        r"""SetMaskCutoff(OESzmapEngineOptions self, double cutoff) -> OESzmapEngineOptions"""
        return _oeszmap.OESzmapEngineOptions_SetMaskCutoff(self, cutoff)

    def GetMaskCutoff(self) -> "double":
        r"""GetMaskCutoff(OESzmapEngineOptions self) -> double"""
        return _oeszmap.OESzmapEngineOptions_GetMaskCutoff(self)

    def SetProbe(self, numOrientations: "unsigned int") -> "OESzmap::OESzmapEngineOptions &":
        r"""SetProbe(OESzmapEngineOptions self, unsigned int numOrientations) -> OESzmapEngineOptions"""
        return _oeszmap.OESzmapEngineOptions_SetProbe(self, numOrientations)

    def GetProbe(self) -> "OEChem::OEMCMolBase const &":
        r"""GetProbe(OESzmapEngineOptions self) -> OEMCMolBase"""
        return _oeszmap.OESzmapEngineOptions_GetProbe(self)

    def GetProbeMol(self, outputMol: "OEMolBase", orientation: "unsigned int"=0) -> "void":
        r"""GetProbeMol(OESzmapEngineOptions self, OEMolBase outputMol, unsigned int orientation=0)"""
        return _oeszmap.OESzmapEngineOptions_GetProbeMol(self, outputMol, orientation)

    def NumOrientations(self) -> "unsigned int":
        r"""NumOrientations(OESzmapEngineOptions self) -> unsigned int"""
        return _oeszmap.OESzmapEngineOptions_NumOrientations(self)

    def GetProbeName(self) -> "char const *":
        r"""GetProbeName(OESzmapEngineOptions self) -> char const *"""
        return _oeszmap.OESzmapEngineOptions_GetProbeName(self)

# Register OESzmapEngineOptions in _oeszmap:
_oeszmap.OESzmapEngineOptions_swigregister(OESzmapEngineOptions)

class OESzmapEngine(object):
    r"""Proxy of C++ OESzmap::OESzmapEngine class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    __swig_destroy__ = _oeszmap.delete_OESzmapEngine

    def __init__(self, *args):
        r"""
        __init__(OESzmapEngine self, OESzmapEngineOptions opt=OESzmap::OESzmapEngineOptions()) -> OESzmapEngine
        __init__(OESzmapEngine self, OEMolBase context, OESzmapEngineOptions opt=OESzmap::OESzmapEngineOptions()) -> OESzmapEngine
        __init__(OESzmapEngine self, OESzmapEngine rhs) -> OESzmapEngine
        """
        _oeszmap.OESzmapEngine_swiginit(self, _oeszmap.new_OESzmapEngine(*args))

    def GetOptions(self) -> "OESzmap::OESzmapEngineOptions const &":
        r"""GetOptions(OESzmapEngine self) -> OESzmapEngineOptions"""
        return _oeszmap.OESzmapEngine_GetOptions(self)

    def SetContext(self, context: "OEMolBase") -> "bool":
        r"""SetContext(OESzmapEngine self, OEMolBase context) -> bool"""
        return _oeszmap.OESzmapEngine_SetContext(self, context)

    def GetContext(self) -> "OEChem::OEMolBase const &":
        r"""GetContext(OESzmapEngine self) -> OEMolBase"""
        return _oeszmap.OESzmapEngine_GetContext(self)

    def CheckAtomTypes(self) -> "bool":
        r"""CheckAtomTypes(OESzmapEngine self) -> bool"""
        return _oeszmap.OESzmapEngine_CheckAtomTypes(self)

    def IsValid(self):
      return _oeszmap.OESzmapEngine___nonzero__(self)



# Register OESzmapEngine in _oeszmap:
_oeszmap.OESzmapEngine_swigregister(OESzmapEngine)

class OESzmapResults(object):
    r"""Proxy of C++ OESzmap::OESzmapResults class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    __swig_destroy__ = _oeszmap.delete_OESzmapResults

    def __init__(self, *args):
        r"""
        __init__(OESzmapResults self) -> OESzmapResults
        __init__(OESzmapResults self, OESzmapResults rhs) -> OESzmapResults
        """
        _oeszmap.OESzmapResults_swiginit(self, _oeszmap.new_OESzmapResults(*args))

    def IsValid(self):
      return _oeszmap.OESzmapResults___nonzero__(self)



    def Clear(self) -> "void":
        r"""Clear(OESzmapResults self)"""
        return _oeszmap.OESzmapResults_Clear(self)

    def GetEnsembleValue(self, ensembleType: "unsigned int") -> "double":
        r"""GetEnsembleValue(OESzmapResults self, unsigned int ensembleType) -> double"""
        return _oeszmap.OESzmapResults_GetEnsembleValue(self, ensembleType)

    def GetComponent(self, *args) -> "bool":
        r"""
        GetComponent(OESzmapResults self, unsigned int componentType) -> OESystem::OEIterBase< double >
        GetComponent(OESzmapResults self, double * compArray, unsigned int componentType) -> bool
        """
        return _oeszmap.OESzmapResults_GetComponent(self, *args)

    def GetProbabilities(self, *args) -> "bool":
        r"""
        GetProbabilities(OESzmapResults self) -> OESystem::OEIterBase< double >
        GetProbabilities(OESzmapResults self, double * probArray) -> bool
        """
        return _oeszmap.OESzmapResults_GetProbabilities(self, *args)

    def GetProbabilityOrder(self, *args) -> "bool":
        r"""
        GetProbabilityOrder(OESzmapResults self) -> OESystem::OEIterBase< unsigned int >
        GetProbabilityOrder(OESzmapResults self, unsigned int * orderArray) -> bool
        """
        return _oeszmap.OESzmapResults_GetProbabilityOrder(self, *args)

    def PlaceProbeMol(self, outputMol: "OEMolBase", orientation: "unsigned int"=0, annotate: "bool"=True) -> "bool":
        r"""PlaceProbeMol(OESzmapResults self, OEMolBase outputMol, unsigned int orientation=0, bool annotate=True) -> bool"""
        return _oeszmap.OESzmapResults_PlaceProbeMol(self, outputMol, orientation, annotate)

    def PlaceProbeSet(self, *args) -> "double":
        r"""
        PlaceProbeSet(OESzmapResults self, OEMCMolBase probeSet, double probCutoff, bool clear=True) -> double
        PlaceProbeSet(OESzmapResults self, OEMCMolBase probeSet, unsigned int maxConfs=0, bool clear=True) -> double
        """
        return _oeszmap.OESzmapResults_PlaceProbeSet(self, *args)

    def PlaceNewAtom(self, *args) -> "OEChem::OEAtomBase *":
        r"""PlaceNewAtom(OESzmapResults self, OEMolBase mol, unsigned int element=) -> OEAtomBase"""
        return _oeszmap.OESzmapResults_PlaceNewAtom(self, *args)

    def GetCoords(self, *args) -> "bool":
        r"""
        GetCoords(OESzmapResults self, double * xyz) -> bool
        GetCoords(OESzmapResults self, float * xyz) -> bool
        """
        return _oeszmap.OESzmapResults_GetCoords(self, *args)

    def NumOrientations(self) -> "unsigned int":
        r"""NumOrientations(OESzmapResults self) -> unsigned int"""
        return _oeszmap.OESzmapResults_NumOrientations(self)

# Register OESzmapResults in _oeszmap:
_oeszmap.OESzmapResults_swigregister(OESzmapResults)


def OEIsClashing(*args) -> "bool":
    r"""
    OEIsClashing(OESzmapEngine szmap, double const * xyz) -> bool
    OEIsClashing(OESzmapEngine szmap, float const * xyz) -> bool
    """
    return _oeszmap.OEIsClashing(*args)

def OECalcSzmapValue(*args) -> "double":
    r"""
    OECalcSzmapValue(OESzmapEngine szmap, double const * xyz, unsigned int ensembleType=OESzmap::OEEnsemble::Default) -> double
    OECalcSzmapValue(OESzmapEngine szmap, float const * xyz, unsigned int ensembleType=OESzmap::OEEnsemble::Default) -> double
    """
    return _oeszmap.OECalcSzmapValue(*args)

def OECalcSzmapResults(*args) -> "bool":
    r"""
    OECalcSzmapResults(OESzmapResults results, OESzmapEngine szmap, double const * xyz) -> bool
    OECalcSzmapResults(OESzmapResults results, OESzmapEngine szmap, float const * xyz) -> bool
    """
    return _oeszmap.OECalcSzmapResults(*args)

def OEGetEnsembleName(ensembleType: "unsigned int", longName: "bool"=False) -> "char const *":
    r"""OEGetEnsembleName(unsigned int ensembleType, bool longName=False) -> char const"""
    return _oeszmap.OEGetEnsembleName(ensembleType, longName)

def OEGetComponentName(componentType: "unsigned int") -> "char const *":
    r"""OEGetComponentName(unsigned int componentType) -> char const *"""
    return _oeszmap.OEGetComponentName(componentType)
OE_OESZMAP_VERSION = _oeszmap.OE_OESZMAP_VERSION


def OESzmapGetRelease() -> "char const *":
    r"""OESzmapGetRelease() -> char const *"""
    return _oeszmap.OESzmapGetRelease()

def OESzmapGetVersion() -> "unsigned int":
    r"""OESzmapGetVersion() -> unsigned int"""
    return _oeszmap.OESzmapGetVersion()

def OESzmapGetArch() -> "char const *":
    r"""OESzmapGetArch() -> char const *"""
    return _oeszmap.OESzmapGetArch()

def OESzmapGetPlatform() -> "char const *":
    r"""OESzmapGetPlatform() -> char const *"""
    return _oeszmap.OESzmapGetPlatform()

def OESzmapIsLicensed(feature: "char const *"=None, expdate: "unsigned int *"=None) -> "bool":
    r"""OESzmapIsLicensed(char const * feature=None, unsigned int * expdate=None) -> bool"""
    return _oeszmap.OESzmapIsLicensed(feature, expdate)

def OESzmapGetLicensee(*args) -> "std::string":
    r"""
    OESzmapGetLicensee(std::string & licensee) -> bool
    OESzmapGetLicensee() -> std::string
    """
    return _oeszmap.OESzmapGetLicensee(*args)

def OESzmapGetSite(*args) -> "std::string":
    r"""
    OESzmapGetSite(std::string & site) -> bool
    OESzmapGetSite() -> std::string
    """
    return _oeszmap.OESzmapGetSite(*args)





#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Align two compounds based on smarts match
#############################################################################
import sys
from openeye import oechem


def SmartsAlign(refmol, fitmol, ss, ofs):
    unique = True
    for match1 in ss.Match(refmol, unique):
        for match2 in ss.Match(fitmol, unique):
            match = oechem.OEMatch()
            for mp1, mp2 in zip(match1.GetAtoms(), match2.GetAtoms()):
                match.AddPair(mp1.target, mp2.target)

            overlay = True
            rmat = oechem.OEDoubleArray(9)
            trans = oechem.OEDoubleArray(3)
            oechem.OERMSD(refmol, fitmol, match, overlay, rmat, trans)
            oechem.OERotate(fitmol, rmat)
            oechem.OETranslate(fitmol, trans)
            oechem.OEWriteConstMolecule(ofs, fitmol)


def main(argv=[__name__]):
    if len(argv) != 5:
        oechem.OEThrow.Usage("%s <refmol> <fitmol> <outfile> <smarts>" % argv[0])

    reffs = oechem.oemolistream()
    if not reffs.open(argv[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[1])
    if not oechem.OEIs3DFormat(reffs.GetFormat()):
        oechem.OEThrow.Fatal("Invalid input format: need 3D coordinates")
    refmol = oechem.OEGraphMol()
    if not oechem.OEReadMolecule(reffs, refmol):
        oechem.OEThrow.Fatal("Unable to read molecule in %s" % argv[1])
    if not refmol.GetDimension() == 3:
        oechem.OEThrow.Fatal("%s doesn't have 3D coordinates" % refmol.GetTitle())

    fitfs = oechem.oemolistream()
    if not fitfs.open(argv[2]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[2])
    if not oechem.OEIs3DFormat(fitfs.GetFormat()):
        oechem.OEThrow.Fatal("Invalid input format: need 3D coordinates")

    ofs = oechem.oemolostream()
    if not ofs.open(argv[3]):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % argv[3])
    if not oechem.OEIs3DFormat(ofs.GetFormat()):
        oechem.OEThrow.Fatal("Invalid output format: need 3D coordinates")

    oechem.OEWriteConstMolecule(ofs, refmol)

    ss = oechem.OESubSearch()
    if not ss.Init(argv[4]):
        oechem.OEThrow.Fatal("Unable to parse SMARTS: %s" % argv[4])

    oechem.OEPrepareSearch(refmol, ss)
    if not ss.SingleMatch(refmol):
        oechem.OEThrow.Fatal("SMARTS fails to match refmol")

    for fitmol in fitfs.GetOEGraphMols():
        if not fitmol.GetDimension() == 3:
            oechem.OEThrow.Warning("%s doesn't have 3D coordinates" % fitmol.GetTitle())
            continue
        oechem.OEPrepareSearch(fitmol, ss)
        if not ss.SingleMatch(fitmol):
            oechem.OEThrow.Warning("SMARTS fails to match fitmol %s" % fitmol.GetTitle())
            continue
        SmartsAlign(refmol, fitmol, ss, ofs)


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Performs substructure search on a molecule using a MDL query and
# generates an image file depicting one match per molecule.
# The output file format depends on its file extension.
#############################################################################

import sys
from openeye import oechem
from openeye import oedepict


def main(argv=[__name__]):

    itf = oechem.OEInterface(InterfaceData)
    oedepict.OEConfigureReportOptions(itf)
    oedepict.OEConfigure2DMolDisplayOptions(itf)
    oedepict.OEConfigureHighlightParams(itf)

    if not oechem.OEParseCommandLine(itf, argv):
        return 1

    qname = itf.GetString("-query")
    tname = itf.GetString("-target")
    oname = itf.GetString("-out")

    ext = oechem.OEGetFileExtension(oname)
    if not oedepict.OEIsRegisteredMultiPageImageFile(ext):
        oechem.OEThrow.Fatal("Unknown multipage image type!")

    qfile = oechem.oemolistream()
    if not qfile.open(qname):
        oechem.OEThrow.Fatal("Cannot open mdl query file!")
    if qfile.GetFormat() != oechem.OEFormat_MDL and qfile.GetFormat() != oechem.OEFormat_SDF:
        oechem.OEThrow.Fatal("Query file has to be an MDL file!")

    ifs = oechem.oemolistream()
    if not ifs.open(tname):
        oechem.OEThrow.Fatal("Cannot open target input file!")

    depictquery = oechem.OEGraphMol()
    if not oechem.OEReadMDLQueryFile(qfile, depictquery):
        oechem.OEThrow.Fatal("Cannot read query molecule!")
    oedepict.OEPrepareDepiction(depictquery)
    queryopts = oechem.OEMDLQueryOpts_Default | oechem.OEMDLQueryOpts_SuppressExplicitH
    qmol = oechem.OEQMol()
    oechem.OEBuildMDLQueryExpressions(qmol, depictquery, queryopts)

    ss = oechem.OESubSearch()
    if not ss.Init(qmol):
        oechem.OEThrow.Fatal("Cannot initialize substructure search!")

    hstyle = oedepict.OEGetHighlightStyle(itf)
    hcolor = oedepict.OEGetHighlightColor(itf)
    align = itf.GetBool("-align")

    ropts = oedepict.OEReportOptions()
    oedepict.OESetupReportOptions(ropts, itf)
    ropts.SetHeaderHeight(140.0)
    report = oedepict.OEReport(ropts)

    dopts = oedepict.OE2DMolDisplayOptions()
    oedepict.OESetup2DMolDisplayOptions(dopts, itf)
    cellwidth, cellheight = report.GetCellWidth(), report.GetCellHeight()
    dopts.SetDimensions(cellwidth, cellheight, oedepict.OEScale_AutoScale)

    unique = True
    for mol in ifs.GetOEGraphMols():

        oechem.OEPrepareSearch(mol, ss)

        miter = ss.Match(mol, unique)
        if not miter.IsValid():
            continue  # no match

        alignres = oedepict.OEAlignmentResult(miter.Target())
        if align:
            alignres = oedepict.OEPrepareAlignedDepiction(mol, ss)
        else:
            oedepict.OEPrepareDepiction(mol)

        cell = report.NewCell()
        disp = oedepict.OE2DMolDisplay(mol, dopts)
        if alignres.IsValid():
            oedepict.OEAddHighlighting(disp, hcolor, hstyle, alignres)
        oedepict.OERenderMolecule(cell, disp)
        oedepict.OEDrawBorder(cell, oedepict.OELightGreyPen)

    # render query structure in each header
    headwidth, headheight = report.GetHeaderWidth(), report.GetHeaderHeight()
    dopts.SetDimensions(headwidth, headheight, oedepict.OEScale_AutoScale)
    disp = oedepict.OE2DMolDisplay(depictquery, dopts)
    for header in report.GetHeaders():
        oedepict.OERenderMolecule(header, disp)
        oedepict.OEDrawBorder(header, oedepict.OELightGreyPen)

    oedepict.OEWriteReport(oname, report)

    return 0


#############################################################################
# INTERFACE
#############################################################################

InterfaceData = '''
!BRIEF [-query] <input> [-target] <input> [-out] <output multipage image> [-align]

!CATEGORY "input/output options :"

  !PARAMETER -query
    !ALIAS -q
    !TYPE string
    !REQUIRED true
    !KEYLESS 1
    !VISIBILITY simple
    !BRIEF Input query filename
  !END

  !PARAMETER -target
    !ALIAS -t
    !TYPE string
    !REQUIRED true
    !KEYLESS 2
    !VISIBILITY simple
    !BRIEF Input target filename
  !END

  !PARAMETER -out
    !ALIAS -o
    !TYPE string
    !REQUIRED true
    !KEYLESS 3
    !VISIBILITY simple
    !BRIEF Output image filename
  !END

!END

!CATEGORY "general options :"

  !PARAMETER -align
    !TYPE bool
    !REQUIRED false
    !DEFAULT false
    !VISIBILITY simple
    !BRIEF Align hits to query
  !END

!END
'''

if __name__ == "__main__":
    sys.exit(main(sys.argv))
